@@ -11,15 +11,17 @@ fight with finding the right module to use.
 """
 
 __appname__ = "sunlight"
-__version__ = "1.2.1"
+__version__ = "1.2.2"
 
 import sunlight.services.openstates
 import sunlight.services.capitolwords
 import sunlight.services.congress
+import sunlight.services.opencivic
 import sunlight.services.congress_deprecated
 
 openstates = sunlight.services.openstates.Openstates()
 capitolwords = sunlight.services.capitolwords.CapitolWords()
+opencivic = sunlight.services.opencivic.OpenCivic()
 
 congress = sunlight.services.congress.Congress()
 congress_deprecated = sunlight.services.congress_deprecated.Congress()
@@ -28,6 +30,7 @@ import os.path
 import warnings
 import sunlight.config
 import sunlight.service
+import sunlight.cache
 
 
 def available_services():
@@ -64,3 +67,6 @@ def _attempt_to_load_apikey():
         pass
 
 _attempt_to_load_apikey()
+
+
+response_cache = sunlight.cache.response_cache
